@@ -148,7 +148,7 @@ execute_perl( SV *function, char *args)
 	XPUSHs ( sv_2mortal (newSVpvn (args, strlen (args))));
 	PUTBACK;
 
-	count = call_sv(function, G_EVAL | G_KEEPERR| G_SCALAR);
+	count = call_sv(function, G_EVAL | G_SCALAR);
 	SPAGAIN;
 
 	sv = GvSV(gv_fetchpv("@", TRUE, SVt_PV));
@@ -184,7 +184,7 @@ timer_cb (void *userdata)
 	XPUSHs (data->userdata);
 	PUTBACK;
 
-	count =	call_sv (data->callback, G_EVAL | G_KEEPERR);
+	count =	call_sv (data->callback, G_EVAL);
 	SPAGAIN;
 	if (SvTRUE (ERRSV))
 	{
@@ -269,7 +269,7 @@ server_cb (char *word[], char *word_eol[], void *userdata)
 	XPUSHs (data->userdata);
 	PUTBACK;
 
-	count =	call_sv (data->callback, G_EVAL | G_KEEPERR);
+	count =	call_sv (data->callback, G_EVAL);
 	SPAGAIN;
 	if (SvTRUE (ERRSV))
 	{
@@ -341,7 +341,7 @@ command_cb (char* word[], char* word_eol[], void *userdata)
 	XPUSHs (data->userdata);
 	PUTBACK;
 
-	count =	call_sv (data->callback, G_EVAL | G_KEEPERR);
+	count =	call_sv (data->callback, G_EVAL);
 	SPAGAIN;
 	if (SvTRUE (ERRSV))
 	{
@@ -402,7 +402,7 @@ print_cb (char *word[], void *userdata)
 	XPUSHs (data->userdata);
 	PUTBACK;
 
-	count =	call_sv (data->callback, G_EVAL | G_KEEPERR);
+	count =	call_sv (data->callback, G_EVAL);
 	SPAGAIN;
 	if (SvTRUE (ERRSV))
 	{
@@ -506,6 +506,7 @@ static XS (XS_Xchat_emit_print)
 {
 	char *event_name;
 	int RETVAL;
+	int count;
 
 	dXSARGS;
 	if (items < 1) {
@@ -513,8 +514,16 @@ static XS (XS_Xchat_emit_print)
 	} else {
 		event_name = (char *)SvPV_nolen (ST (0));
 		RETVAL = 0;
-	  
-		switch  (items) {
+		
+		/* we need to figure out the number of defined values passed in */
+		for( count = 0; count < items; count++ ) {
+		  if (!SvOK (ST (count) )) {
+			 break;
+		  }
+		}
+
+		/*		switch  (items) {*/
+		switch (count) {
 		case 1:
 			RETVAL = xchat_emit_print (ph, event_name, NULL);
 			break;
@@ -1076,7 +1085,7 @@ perl_print_cb (char *word[], void *perl_callback)
 	}
 	PUTBACK;
 
-	count = call_pv( (char*)perl_callback, G_EVAL | G_KEEPERR );
+	count = call_pv( (char*)perl_callback, G_EVAL);
 
 	SPAGAIN;
 
@@ -1998,7 +2007,8 @@ xs_init (pTHX)
 	newCONSTSUB (stash, "EAT_XCHAT", newSViv (XCHAT_EAT_XCHAT));
 	newCONSTSUB (stash, "EAT_PLUGIN", newSViv (XCHAT_EAT_PLUGIN));
 	newCONSTSUB (stash, "EAT_ALL", newSViv (XCHAT_EAT_ALL));
-
+	newCONSTSUB (stash, "KEEP", newSViv(1));
+	newCONSTSUB (stash, "REMOVE", newSViv(0));
 }
 
 static void
@@ -2020,252 +2030,288 @@ perl_init (void)
 	     We also redefine the $SIG{__WARN__} handler to have XChat
 	     printing warnings in the main window. (TheHobbit)*/
 
-"BEGIN {\n"
-"  $INC{'Xchat.pm'} = 'DUMMY';\n"
-"}\n"
-"\n"
-"{\n"
-"  package Xchat;\n"
-"  use base qw(Exporter);\n"
-"  our @EXPORT = (qw(PRI_HIGHEST PRI_HIGH PRI_NORM PRI_LOW PRI_LOWEST),\n"
-"					  qw(EAT_NONE EAT_XCHAT EAT_PLUGIN EAT_ALL),\n"
-"					 );\n"
-"  our @EXPORT_OK = (qw(register hook_server hook_command hook_print),\n"
-"						  qw(hook_timer unhook print command find_context),\n"
-"						  qw(get_context set_context get_info get_prefs emit_print),\n"
-"						  qw(nickcmp get_list),\n"
-"						  qw(PRI_HIGHEST PRI_HIGH PRI_NORM PRI_LOW PRI_LOWEST),\n"
-"						  qw(EAT_NONE EAT_XCHAT EAT_PLUGIN EAT_ALL),\n"
-"						 );\n"
-"  our %EXPORT_TAGS = ( all => [\n"
-"										 qw(register hook_server hook_command),\n"
-"										 qw(hook_print hook_timer unhook print command),\n"
-"										 qw(find_context get_context set_context),\n"
-"										 qw(get_info get_prefs emit_print nickcmp),\n"
-"										 qw(get_list),\n"
-"										 qw(PRI_HIGHEST PRI_HIGH PRI_NORM PRI_LOW),\n"
-"										 qw(PRI_LOWEST EAT_NONE EAT_XCHAT EAT_PLUGIN),\n"
-"										 qw(EAT_ALL),\n"
-"										],\n"
-"							  contants => [\n"
-"												qw(PRI_HIGHEST PRI_HIGH PRI_NORM PRI_LOW),\n"
-"												qw(PRI_LOWEST EAT_NONE EAT_XCHAT),\n"
-"												qw(EAT_PLUGIN EAT_ALL),\n"
-"											  ],\n"
-"							  hooks => [\n"
-"											qw(hook_server hook_command),\n"
-"											qw(hook_print hook_timer unhook),\n"
-"										  ],\n"
-"							  util => [\n"
-"										  qw(register print command find_context),\n"
-"										  qw(get_context set_context get_info get_prefs),\n"
-"										  qw(emit_print nickcmp get_list),\n"
-"										 ],\n"
-"							);\n"
-"\n"
-"}\n"
-"sub Xchat::hook_server {\n"
-"  return undef unless @_ >= 2;\n"
-"  \n"
-"  my $message = shift;\n"
-"  my $callback = shift;\n"
-"  my $options = shift;\n"
-"  \n"
-"  my ($priority, $data) = ( Xchat::PRI_NORM, undef );\n"
-"  \n"
-"  if ( ref( $options ) eq 'HASH' ) {\n"
-"	 if ( exists( $options->{priority} ) && defined( $options->{priority} ) ) {\n"
-"		$priority = $options->{priority};\n"
-"    }\n"
-"    if ( exists( $options->{data} ) && defined( $options->{data} ) ) {\n"
-"      $data = $options->{data};\n"
-"    }\n"
-"  }\n"
-"  \n"
-"  return Xchat::_hook_server( $message, $priority, $callback, $data);\n"
-"\n"
-"}\n"
-"\n"
-"sub Xchat::hook_command {\n"
-"  return undef unless @_ >= 2;\n"
-"\n"
-"  my $command = shift;\n"
-"  my $callback = shift;\n"
-"  my $options = shift;\n"
-"\n"
-"  my ($priority, $help_text, $data) = ( Xchat::PRI_NORM, '', undef );\n"
-"\n"
-"  if ( ref( $options ) eq 'HASH' ) {\n"
-"    if ( exists( $options->{priority} ) && defined( $options->{priority} ) ) {\n"
-"      $priority = $options->{priority};\n"
-"    }\n"
-"    if ( exists( $options->{help_text} ) && defined( $options->{help_text} ) ) {\n"
-"      $help_text = $options->{help_text};\n"
-"    }\n"
-"    if ( exists( $options->{data} ) && defined( $options->{data} ) ) {\n"
-"      $data = $options->{data};\n"
-"    }\n"
-"  }\n"
-"\n"
-"  return Xchat::_hook_command( $command, $priority, $callback, $help_text,\n"
-"			       $data);\n"
-"\n"
-"}\n"
-"\n"
-"sub Xchat::hook_print {\n"
-"  return undef unless @_ >= 2;\n"
-"\n"
-"  my $event = shift;\n"
-"  my $callback = shift;\n"
-"  my $options = shift;\n"
-"\n"
-"  my ($priority, $data) = ( Xchat::PRI_NORM, undef );\n"
-"\n"
-"  if ( ref( $options ) eq 'HASH' ) {\n"
-"    if ( exists( $options->{priority} ) && defined( $options->{priority} ) ) {\n"
-"      $priority = $options->{priority};\n"
-"    }\n"
-"    if ( exists( $options->{data} ) && defined( $options->{data} ) ) {\n"
-"      $data = $options->{data};\n"
-"    }\n"
-"  }\n"
-"\n"
-"  return Xchat::_hook_print( $event, $priority, $callback, $data);\n"
-"\n"
-"}\n"
-"\n"
-"\n"
-"sub Xchat::hook_timer {\n"
-"  return undef unless @_ >= 2;\n"
-"\n"
-"  my $timeout = shift;\n"
-"  my $callback = shift;\n"
-"  my $data = shift;\n"
-"\n"
-"  if( ref( $data ) eq 'HASH' && exists( $data->{data} )\n"
-"      && defined( $data->{data} ) ) {\n"
-"    $data = $data->{data};\n"
-"  }\n"
-"\n"
-"  return Xchat::_hook_timer( $timeout, $callback, $data );\n"
-"\n"
-"}\n"
-"\n"
-"sub Xchat::print {\n"
-"\n"
-"  my $text = shift @_;\n"
-"  if( ref( $text ) eq 'ARRAY' ) {\n"
-"    if( $, ) {\n"
-"      $text = join $, , @$text;\n"
-"    } else {\n"
-"      $text = join \"\", @$text;\n"
-"    }\n"
-"  }\n"
-"\n"
-"  \n"
-"  if( @_ >= 1 ) {\n"
-"    my $channel = shift @_;\n"
-"	 my $server = shift @_;\n"
-"    my $old_ctx = Xchat::get_context();\n"
-"    my $ctx = Xchat::find_context( $channel, $server );\n"
-"    \n"
-"    if( $ctx ) {\n"
-"      Xchat::set_context( $ctx );\n"
-"      Xchat::_print( $text );\n"
-"      Xchat::set_context( $old_ctx );\n"
-"      return 1;\n"
-"    } else {\n"
-"      return 0;\n"
-"    }\n"
-"  } else {\n"
-"    Xchat::_print( $text );\n"
-"    return 1;\n"
-"  }\n"
-"\n"
-"}\n"
-"\n"
-"sub Xchat::printf {\n"
-"  my $format = shift;\n"
-"  Xchat::print( sprintf( $format, @_ ) );\n"
-"}\n"
-"\n"
-"sub Xchat::command {\n"
-"\n"
-"  my $command = shift;\n"
-"  my @commands;\n"
-"  if( ref( $command ) eq 'ARRAY' ) {\n"
-"	 @commands = @$command;\n"
-"  } else {\n"
-"	 @commands = ($command);\n"
-"  }\n"
-"  if( @_ >= 1 ) {\n"
-"    my ($channel, $server) = @_;\n"
-"    my $old_ctx = Xchat::get_context();\n"
-"    my $ctx = Xchat::find_context( $channel, $server );\n"
-"\n"
-"    if( $ctx ) {\n"
-"      Xchat::set_context( $ctx );\n"
-"      Xchat::_command( $_ ) foreach @commands;\n"
-"      Xchat::set_context( $old_ctx );\n"
-"      return 1;\n"
-"    } else {\n"
-"      return 0;\n"
-"    }\n"
-"  } else {\n"
-"    Xchat::_command( $_ ) foreach @commands;\n"
-"    return 1;\n"
-"  }\n"
-"\n"
-"}\n"
-"\n"
-"sub Xchat::commandf {\n"
-"  my $format = shift;\n"
-"  Xchat::command( sprintf( $format, @_ ) );\n"
-"}\n"
-"\n"
-"sub Xchat::user_info {\n"
-"  my $nick = shift @_ || Xchat::get_info( \"nick\" );\n"
-"  my $user;\n"
-"\n"
-"  for(Xchat::get_list( \"users\" ) ) {\n"
-"	 if( Xchat::nickcmp( $_->{nick}, $nick ) == 0 ) {\n"
-"		$user = $_;\n"
-"		last;\n"
-"	 }\n"
-"  }\n"
-"  return $user;\n"
-"}\n"
-"\n"
-"$SIG{__WARN__} = sub {\n"
-"  local $, = \"\\n\";\n"
-"  my ($package, $line, $sub) = caller(1);\n"
-"  Xchat::print( \"Warning from ${package}::${sub} at line $line.\" );\n"
-"  Xchat::print( @_ );\n"
-"};\n"
-"\n"
-"sub Embed::load {\n"
-"  my $file = shift @_;\n"
-"\n"
-"  if( open FH, $file ) {\n"
-"	 my $data = do {local $/; <FH>};\n"
-"	 close FH;\n"
-"\n"
-"	 eval $data;\n"
-"\n"
-"	 if( $@ ) {\n"
-"		# something went wrong\n"
-"		Xchat::print( \"Error loading '$file':\\n$@\n\" );\n"
-"		return 1;\n"
-"	 }\n"
-"\n"
-"  } else {\n"
-"\n"
-"	 Xchat::print( \"Error opening '$file': $!\\n\" );\n"
-"	 return 2;\n"
-"  }\n"
-"\n"
-"  return 0;\n"
-"}\n"
+	  "BEGIN {\n"
+	  "$INC{'Xchat.pm'} = 'DUMMY';\n"
+	  "}\n"
+
+	  "{\n"
+	  "package Xchat;\n"
+	  "use base qw(Exporter);\n"
+	  "our @EXPORT = (qw(PRI_HIGHEST PRI_HIGH PRI_NORM PRI_LOW PRI_LOWEST),\n"
+	  "qw(EAT_NONE EAT_XCHAT EAT_PLUGIN EAT_ALL),\n"
+	  ");\n"
+	  "our @EXPORT_OK = (qw(register hook_server hook_command hook_print),\n"
+	  "qw(hook_timer unhook print command find_context),\n"
+	  "qw(get_context set_context get_info get_prefs emit_print),\n"
+	  "qw(nickcmp get_list context_info strip_code),\n"
+	  "qw(PRI_HIGHEST PRI_HIGH PRI_NORM PRI_LOW PRI_LOWEST),\n"
+	  "qw(EAT_NONE EAT_XCHAT EAT_PLUGIN EAT_ALL),\n"
+	  ");\n"
+	  "our %EXPORT_TAGS = ( all => [\n"
+	  "qw(register hook_server hook_command),\n"
+	  "qw(hook_print hook_timer unhook print command),\n"
+	  "qw(find_context get_context set_context),\n"
+	  "qw(get_info get_prefs emit_print nickcmp),\n"
+	  "qw(get_list context_info strip_code),\n"
+	  "qw(PRI_HIGHEST PRI_HIGH PRI_NORM PRI_LOW),\n"
+	  "qw(PRI_LOWEST EAT_NONE EAT_XCHAT EAT_PLUGIN),\n"
+	  "qw(EAT_ALL),\n"
+	  "],\n"
+	  "constants => [\n"
+	  "qw(PRI_HIGHEST PRI_HIGH PRI_NORM PRI_LOW),\n"
+	  "qw(PRI_LOWEST EAT_NONE EAT_XCHAT),\n"
+	  "qw(EAT_PLUGIN EAT_ALL),\n"
+	  "],\n"
+	  "hooks => [\n"
+	  "qw(hook_server hook_command),\n"
+	  "qw(hook_print hook_timer unhook),\n"
+	  "],\n"
+	  "util => [\n"
+	  "qw(register print command find_context),\n"
+	  "qw(get_context set_context get_info get_prefs),\n"
+	  "qw(emit_print nickcmp get_list context_info),\n"
+	  "qw(strip_code),\n"
+	  "],\n"
+	  ");\n"
+
+	  "}\n"
+	  "sub Xchat::hook_server {\n"
+	  "return undef unless @_ >= 2;\n"
+  
+	  "my $message = shift;\n"
+	  "my $callback = shift;\n"
+	  "my $options = shift;\n"
+  
+	  "my ($priority, $data) = ( Xchat::PRI_NORM, undef );\n"
+  
+	  "if ( ref( $options ) eq 'HASH' ) {\n"
+	  "if ( exists( $options->{priority} ) && defined( $options->{priority} ) ) {\n"
+	  "$priority = $options->{priority};\n"
+	  "}\n"
+	  "if ( exists( $options->{data} ) && defined( $options->{data} ) ) {\n"
+	  "$data = $options->{data};\n"
+	  "}\n"
+	  "}\n"
+  
+	  "return Xchat::_hook_server( $message, $priority, $callback, $data);\n"
+
+	  "}\n"
+
+	  "sub Xchat::hook_command {\n"
+	  "return undef unless @_ >= 2;\n"
+
+	  "my $command = shift;\n"
+	  "my $callback = shift;\n"
+	  "my $options = shift;\n"
+
+	  "my ($priority, $help_text, $data) = ( Xchat::PRI_NORM, '', undef );\n"
+
+	  "if ( ref( $options ) eq 'HASH' ) {\n"
+	  "if ( exists( $options->{priority} ) && defined( $options->{priority} ) ) {\n"
+	  "$priority = $options->{priority};\n"
+	  "}\n"
+	  "if ( exists( $options->{help_text} ) && defined( $options->{help_text} ) ) {\n"
+	  "$help_text = $options->{help_text};\n"
+	  "}\n"
+	  "if ( exists( $options->{data} ) && defined( $options->{data} ) ) {\n"
+	  "$data = $options->{data};\n"
+	  "}\n"
+	  "}\n"
+
+	  "return Xchat::_hook_command( $command, $priority, $callback, $help_text,\n"
+	  "$data);\n"
+
+	  "}\n"
+
+	  "sub Xchat::hook_print {\n"
+	  "return undef unless @_ >= 2;\n"
+
+	  "my $event = shift;\n"
+	  "my $callback = shift;\n"
+	  "my $options = shift;\n"
+
+	  "my ($priority, $data) = ( Xchat::PRI_NORM, undef );\n"
+
+	  "if ( ref( $options ) eq 'HASH' ) {\n"
+	  "if ( exists( $options->{priority} ) && defined( $options->{priority} ) ) {\n"
+	  "$priority = $options->{priority};\n"
+	  "}\n"
+	  "if ( exists( $options->{data} ) && defined( $options->{data} ) ) {\n"
+	  "$data = $options->{data};\n"
+	  "}\n"
+	  "}\n"
+
+	  "return Xchat::_hook_print( $event, $priority, $callback, $data);\n"
+
+	  "}\n"
+
+
+	  "sub Xchat::hook_timer {\n"
+	  "return undef unless @_ >= 2;\n"
+
+	  "my $timeout = shift;\n"
+	  "my $callback = shift;\n"
+	  "my $data = shift;\n"
+
+	  "if( ref( $data ) eq 'HASH' && exists( $data->{data} )\n"
+	  "&& defined( $data->{data} ) ) {\n"
+	  "$data = $data->{data};\n"
+	  "}\n"
+
+	  "return Xchat::_hook_timer( $timeout, $callback, $data );\n"
+
+	  "}\n"
+
+	  "sub Xchat::print {\n"
+
+	  "my $text = shift @_;\n"
+	  "if( ref( $text ) eq 'ARRAY' ) {\n"
+	  "if( $, ) {\n"
+	  "$text = join $, , @$text;\n"
+	  "} else {\n"
+	  "$text = join \"\", @$text;\n"
+	  "}\n"
+	  "}\n"
+  
+	  "if( @_ >= 1 ) {\n"
+	  "my $channel = shift @_;\n"
+	  "my $server = shift @_;\n"
+	  "my $old_ctx = Xchat::get_context();\n"
+	  "my $ctx = Xchat::find_context( $channel, $server );\n"
+    
+	  "if( $ctx ) {\n"
+	  "Xchat::set_context( $ctx );\n"
+	  "Xchat::_print( $text );\n"
+	  "Xchat::set_context( $old_ctx );\n"
+	  "return 1;\n"
+	  "} else {\n"
+	  "return 0;\n"
+	  "}\n"
+	  "} else {\n"
+	  "Xchat::_print( $text );\n"
+	  "return 1;\n"
+	  "}\n"
+
+	  "}\n"
+
+	  "sub Xchat::printf {\n"
+	  "my $format = shift;\n"
+	  "Xchat::print( sprintf( $format, @_ ) );\n"
+	  "}\n"
+
+	  "sub Xchat::command {\n"
+
+	  "my $command = shift;\n"
+	  "my @commands;\n"
+	  "if( ref( $command ) eq 'ARRAY' ) {\n"
+	  "@commands = @$command;\n"
+	  "} else {\n"
+	  "@commands = ($command);\n"
+	  "}\n"
+	  "if( @_ >= 1 ) {\n"
+	  "my ($channel, $server) = @_;\n"
+	  "my $old_ctx = Xchat::get_context();\n"
+	  "my $ctx = Xchat::find_context( $channel, $server );\n"
+
+	  "if( $ctx ) {\n"
+	  "Xchat::set_context( $ctx );\n"
+	  "Xchat::_command( $_ ) foreach @commands;\n"
+	  "Xchat::set_context( $old_ctx );\n"
+	  "return 1;\n"
+	  "} else {\n"
+	  "return 0;\n"
+	  "}\n"
+	  "} else {\n"
+	  "Xchat::_command( $_ ) foreach @commands;\n"
+	  "return 1;\n"
+	  "}\n"
+
+	  "}\n"
+
+	  "sub Xchat::commandf {\n"
+	  "my $format = shift;\n"
+	  "Xchat::command( sprintf( $format, @_ ) );\n"
+	  "}\n"
+
+	  "sub Xchat::user_info {\n"
+	  "my $nick = shift @_ || Xchat::get_info( \"nick\" );\n"
+	  "my $user;\n"
+
+	  "for(Xchat::get_list( \"users\" ) ) {\n"
+	  "if( Xchat::nickcmp( $_->{nick}, $nick ) == 0 ) {\n"
+	  "$user = $_;\n"
+	  "last;\n"
+	  "}\n"
+	  "}\n"
+	  "return $user;\n"
+	  "}\n"
+
+	  "sub Xchat::context_info {\n"
+	  "my $ctx = shift @_;\n"
+	  "my $old_ctx = Xchat::get_context;\n"
+	  "my @fields = (qw(away channel host network nick server topic version),\n"
+	  "qw(win_status xchatdir xchatdirfs),\n"
+	  ");\n"
+
+	  "Xchat::set_context( $ctx );\n"
+	  "my %info;\n"
+	  "for my $field ( @fields ) {\n"
+	  "$info{$field} = Xchat::get_info( $field );\n"
+	  "}\n"
+	  "Xchat::set_context( $old_ctx );\n"
+
+	  "return %info if wantarray;\n"
+	  "return \\%info;\n"
+	  "}\n"
+
+	  "sub Xchat::strip_code {\n"
+	  "my $pattern =\n"
+	  "qr/\\cB| #Bold\n"
+	  "\\cC\\d{0,2}(?:,\\d{0,2})?| #Color\n"
+	  "\\cG| #Beep\n"
+	  "\\cO| #Reset\n"
+	  "\\cV| #Reverse\n"
+	  "\\c_  #Underline\n"
+	  "/x;\n"
+
+	  "if( defined wantarray ) {\n"
+	  "my $msg = shift;\n"
+	  "$msg =~ s/$pattern//g;\n"
+	  "return $msg;\n"
+	  "} else {\n"
+	  "$_[0] =~ s/$pattern//g;\n"
+	  "}\n"
+	  "}\n"
+
+	  "$SIG{__WARN__} = sub {\n"
+	  "local $, = \"\\n\";\n"
+	  "my ($package, $file, $line, $sub) = caller(1);\n"
+	  "Xchat::print( \"Warning from ${sub}.\" );\n"
+	  "Xchat::print( @_ );\n"
+	  "};\n"
+
+	  "sub Xchat::Embed::load {\n"
+	  "my $file = shift @_;\n"
+
+	  "if( open FH, $file ) {\n"
+	  "my $data = do {local $/; <FH>};\n"
+	  "close FH;\n"
+
+	  "eval $data;\n"
+
+	  "if( $@ ) {\n"
+	  "Xchat::print( \"Error loading '$file':\\n$@\\n\" );\n"
+	  "return 1;\n"
+	  "}\n"
+
+	  "} else {\n"
+
+	  "Xchat::print( \"Error opening '$file': $!\\n\" );\n"
+	  "return 2;\n"
+	  "}\n"
+
+	  "return 0;\n"
+	  "}\n"
 
 	};
 #ifdef ENABLE_NLS
@@ -2329,7 +2375,7 @@ perl_load_file (char *script_name)
 		perl_init ();
 	}
 
-	return execute_perl (sv_2mortal (newSVpvn ("Embed::load", 11)),
+	return execute_perl (sv_2mortal (newSVpv ("Xchat::Embed::load", 0)),
 								  script_name);
 	
 }
