@@ -37,6 +37,7 @@
 #include "outbound.h"
 #include "inbound.h"
 #include "server.h"
+#include "servlist.h"
 #include "text.h"
 #include "ctcp.h"
 #include "plugin.h"
@@ -47,7 +48,7 @@
 /* also light/dark gray (14/15) */
 /* 5,7,8 are all shades of yellow which happen to look dman near the same */
 
-static char rcolors[] = { 3, 4, 6, 8, 9, 10, 11, 12, 13 };
+static char rcolors[] = { 19, 20, 22, 24, 25, 26, 27, 28, 29 };
 
 static int
 color_of (char *name)
@@ -133,15 +134,25 @@ find_session_from_nick (char *nick, server *serv)
 	return 0;
 }
 
-void
-inbound_privmsg (server *serv, char *from, char *ip, char *text)
+static session *
+inbound_open_dialog (server *serv, char *from)
 {
 	session *sess;
 
-	sess = find_dialog (serv, from);
+	sess = new_ircwindow (serv, from, SESS_DIALOG, 0);
+	/* for playing sounds */
+	EMIT_SIGNAL (XP_TE_OPENDIALOG, sess, NULL, NULL, NULL, NULL, 0);
 
-	if (prefs.beepmsg || (sess && sess->beep))
-		fe_beep ();
+	return sess;
+}
+
+void
+inbound_privmsg (server *serv, char *from, char *ip, char *text, int id)
+{
+	session *sess;
+	char idtext[64];
+
+	sess = find_dialog (serv, from);
 
 	if (sess || prefs.autodialog)
 	{
@@ -149,10 +160,15 @@ inbound_privmsg (server *serv, char *from, char *ip, char *text)
 		if (!sess)
 		{
 			if (flood_check (from, ip, serv, current_sess, 1))
-				sess = new_ircwindow (serv, from, SESS_DIALOG);	/* Create a dialog session */
+				/* Create a dialog session */
+				sess = inbound_open_dialog (serv, from);
 			else
 				sess = serv->server_session;
 		}
+
+		if (prefs.beepmsg || (sess && sess->beep))
+			sound_beep (sess);
+
 		if (ip && ip[0])
 		{
 			if (prefs.logging && sess->logfd != -1 &&
@@ -164,22 +180,39 @@ inbound_privmsg (server *serv, char *from, char *ip, char *text)
 			}
 			set_topic (sess, ip);
 		}
-		inbound_chanmsg (serv, NULL, NULL, from, text, FALSE);
+		inbound_chanmsg (serv, NULL, NULL, from, text, FALSE, id);
 		return;
 	}
 
+	if (id)
+	{
+		safe_strcpy (idtext, prefs.irc_id_ytext, sizeof (idtext));
+	} else
+	{
+		safe_strcpy (idtext, prefs.irc_id_ntext, sizeof (idtext));
+	}
+	/* convert codes like %C,%U to the proper ones */
+	check_special_chars (idtext, TRUE);
+
 	sess = find_session_from_nick (from, serv);
 	if (!sess)
 	{
 		sess = serv->front_session;
-		EMIT_SIGNAL (XP_TE_PRIVMSG, sess, from, text, NULL, NULL, 0);
+
+		if (prefs.beepmsg || (sess && sess->beep))
+			sound_beep (sess);
+
+		EMIT_SIGNAL (XP_TE_PRIVMSG, sess, from, text, idtext, NULL, 0);
 		return;
 	}
 
+	if (prefs.beepmsg || sess->beep)
+		sound_beep (sess);
+
 	if (sess->type == SESS_DIALOG)
-		EMIT_SIGNAL (XP_TE_DPRIVMSG, sess, from, text, NULL, NULL, 0);
+		EMIT_SIGNAL (XP_TE_DPRIVMSG, sess, from, text, idtext, NULL, 0);
 	else
-		EMIT_SIGNAL (XP_TE_PRIVMSG, sess, from, text, NULL, NULL, 0);
+		EMIT_SIGNAL (XP_TE_PRIVMSG, sess, from, text, idtext, NULL, 0);
 }
 
 static int
@@ -266,7 +299,7 @@ inbound_action (session *sess, char *chan, char *from, char *text, int fromme)
 			sess = find_dialog (serv, from);
 			/* if non found, open a new one */
 			if (!sess && prefs.autodialog)
-				sess = new_ircwindow (serv, from, SESS_DIALOG);
+				sess = inbound_open_dialog (serv, from);
 		}
 	}
 
@@ -293,7 +326,7 @@ inbound_action (session *sess, char *chan, char *from, char *text, int fromme)
 			beep = TRUE;
 
 		if (beep || sess->beep)
-			fe_beep ();
+			sound_beep (sess);
 
 		if (hilight)
 		{
@@ -314,11 +347,12 @@ inbound_action (session *sess, char *chan, char *from, char *text, int fromme)
 }
 
 void
-inbound_chanmsg (server *serv, session *sess, char *chan, char *from, char *text, char fromme)
+inbound_chanmsg (server *serv, session *sess, char *chan, char *from, char *text, char fromme, int id)
 {
 	struct User *user;
 	int hilight = FALSE;
 	char nickchar[2] = "\000";
+	char idtext[64];
 
 	if (!sess)
 	{
@@ -356,28 +390,38 @@ inbound_chanmsg (server *serv, session *sess, char *chan, char *from, char *text
 		return;
 	}
 
+	if (id)
+	{
+		safe_strcpy (idtext, prefs.irc_id_ytext, sizeof (idtext));
+	} else
+	{
+		safe_strcpy (idtext, prefs.irc_id_ntext, sizeof (idtext));
+	}
+	/* convert codes like %C,%U to the proper ones */
+	check_special_chars (idtext, TRUE);
+
 	if (sess->type != SESS_DIALOG)
 		if (prefs.beepchans || sess->beep)
-			fe_beep ();
+			sound_beep (sess);
 
 	if (is_hilight (text, sess, serv))
 	{
 		hilight = TRUE;
 		if (prefs.beephilight)
-			fe_beep ();
+			sound_beep (sess);
 	}
 	if (sess->type == SESS_DIALOG)
-		EMIT_SIGNAL (XP_TE_DPRIVMSG, sess, from, text, NULL, NULL, 0);
+		EMIT_SIGNAL (XP_TE_DPRIVMSG, sess, from, text, idtext, NULL, 0);
 	else if (hilight)
-		EMIT_SIGNAL (XP_TE_HCHANMSG, sess, from, text, nickchar, NULL, 0);
+		EMIT_SIGNAL (XP_TE_HCHANMSG, sess, from, text, nickchar, idtext, 0);
 	else if (prefs.colorednicks)
 	{
 		char tbuf[NICKLEN + 4];
 		snprintf (tbuf, sizeof (tbuf), "\003%d%s", color_of (from), from);
-		EMIT_SIGNAL (XP_TE_CHANMSG, sess, tbuf, text, nickchar, NULL, 0);
+		EMIT_SIGNAL (XP_TE_CHANMSG, sess, tbuf, text, nickchar, idtext, 0);
 	}
 	else
-		EMIT_SIGNAL (XP_TE_CHANMSG, sess, from, text, nickchar, NULL, 0);
+		EMIT_SIGNAL (XP_TE_CHANMSG, sess, from, text, nickchar, idtext, 0);
 }
 
 void
@@ -481,7 +525,7 @@ inbound_ujoin (server *serv, char *chan, char *nick, char *ip)
 			sess = find_unused_session (serv);
 			if (!sess)
 				/* last resort, open a new tab/window */
-				sess = new_ircwindow (serv, chan, SESS_CHANNEL);
+				sess = new_ircwindow (serv, chan, SESS_CHANNEL, 1);
 		}
 	}
 
@@ -699,11 +743,12 @@ set_server_name (struct server *serv, char *name)
 			fe_set_title (sess);
 		list = list->next;
 	}
+
 	if (serv->server_session->type == SESS_SERVER)
 	{
-		if (serv->networkname)
+		if (serv->network)
 		{
-			safe_strcpy (serv->server_session->channel, serv->networkname, CHANLEN);
+			safe_strcpy (serv->server_session->channel, ((ircnet *)serv->network)->name, CHANLEN);
 		} else
 		{
 			safe_strcpy (serv->server_session->channel, name, CHANLEN);
@@ -797,7 +842,7 @@ find_session_from_type (int type, server *serv)
 }
 
 void
-inbound_notice (server *serv, char *to, char *nick, char *msg, char *ip)
+inbound_notice (server *serv, char *to, char *nick, char *msg, char *ip, int id)
 {
 	char *po,*ptr=to;
 	session *sess = 0;
@@ -833,9 +878,9 @@ inbound_notice (server *serv, char *to, char *nick, char *msg, char *ip)
 				register unsigned int oldh = prefs.hideuserlist;
 				prefs.hideuserlist = 1;
 				if (stype == SESS_NOTICES)
-					sess = new_ircwindow (serv, "(notices)", SESS_NOTICES);
+					sess = new_ircwindow (serv, "(notices)", SESS_NOTICES, 0);
 				else
-					sess = new_ircwindow (serv, "(snotices)", SESS_SNOTICES);
+					sess = new_ircwindow (serv, "(snotices)", SESS_SNOTICES, 0);
 				prefs.hideuserlist = oldh;
 				fe_set_channel (sess);
 				fe_set_title (sess);
@@ -1189,9 +1234,17 @@ inbound_login_end (session *sess, char *text)
 		}
 		set_default_modes (serv);
 
-		/* there may be more than 1, separated by \n */
-		if (serv->eom_cmd)
-			token_foreach (serv->eom_cmd, '\n', inbound_exec_eom_cmd, sess);
+		if (serv->network)
+		{
+			/* there may be more than 1, separated by \n */
+			if (((ircnet *)serv->network)->command)
+				token_foreach (((ircnet *)serv->network)->command, '\n',
+									inbound_exec_eom_cmd, sess);
+
+			/* send nickserv password */
+			if (((ircnet *)serv->network)->nickserv)
+				serv->p_nickserv (serv, ((ircnet *)serv->network)->nickserv);
+		}
 
 		check_willjoin_channels (serv);
 		if (serv->supports_watch)
