@@ -627,13 +627,13 @@ inbound_005 (server * serv, char *word[])
 			serv->supports_watch = TRUE;
 		} else if (strncmp (word[w], "NETWORK=", 8) == 0)
 		{
-			if (serv->networkname)
+/*			if (serv->networkname)
 				free (serv->networkname);
-			serv->networkname = strdup (word[w] + 8);
+			serv->networkname = strdup (word[w] + 8);*/
 
 			if (serv->server_session->type == SESS_SERVER)
 			{
-				safe_strcpy (serv->server_session->channel, serv->networkname, CHANLEN);
+				safe_strcpy (serv->server_session->channel, word[w] + 8, CHANLEN);
 				fe_set_channel (serv->server_session);
 			}
 
@@ -656,6 +656,12 @@ inbound_005 (server * serv, char *word[])
 		} else if (strcmp (word[w], "WHOX") == 0)
 		{
 			serv->have_whox = TRUE;
+		} else if (strcmp (word[w], "CAPAB") == 0)
+		{
+			serv->have_capab = TRUE;
+									/* 12345678901234567890 */
+			tcp_send_len (serv, "CAPAB IDENTIFY-MSG\r\n", 20);
+			/* now wait for numeric 290 */	
 		}
 
 		w++;
