@@ -27,6 +27,7 @@
 #include "outbound.h"
 #include "cfgfiles.h"
 #include "ignore.h"
+#include "modes.h"
 #include "notify.h"
 #include "text.h"
 #define PLUGIN_C
@@ -387,12 +388,12 @@ plugin_load (session *sess, char *filename, char *arg)
 	else
 		handle = dlopen (filename, RTLD_GLOBAL | RTLD_NOW);
 	if (handle == NULL)
-		return dlerror ();
+		return (char *)dlerror ();
 	dlerror ();		/* Clear any existing error */
 
 	/* find the init routine xchat_plugin_init */
 	init_func = dlsym (handle, "xchat_plugin_init");
-	error = dlerror ();
+	error = (char *)dlerror ();
 	if (error != NULL)
 	{
 		dlclose (handle);
@@ -401,7 +402,7 @@ plugin_load (session *sess, char *filename, char *arg)
 
 	/* find the plugin's deinit routine, if any */
 	deinit_func = dlsym (handle, "xchat_plugin_deinit");
-	error = dlerror ();
+	error = (char *)dlerror ();
 #endif
 
 	/* add it to our linked list */
@@ -866,6 +867,7 @@ xchat_find_context (xchat_plugin *ph, const char *servname, const char *channel)
 	GSList *slist, *clist;
 	server *serv;
 	session *sess;
+	char *netname;
 
 	if (servname == NULL && channel == NULL)
 		return current_sess;
@@ -874,10 +876,12 @@ xchat_find_context (xchat_plugin *ph, const char *servname, const char *channel)
 	while (slist)
 	{
 		serv = slist->data;
+		netname = get_network (serv->front_session, TRUE);
+
 		if (servname == NULL ||
 			 rfc_casecmp (servname, serv->servername) == 0 ||
 			 strcasecmp (servname, serv->hostname) == 0 ||
-			 (serv->networkname && strcasecmp (servname, serv->networkname) == 0))
+			 strcasecmp (servname, netname) == 0)
 		{
 			if (channel == NULL)
 				return serv->front_session;
@@ -925,8 +929,14 @@ xchat_get_info (xchat_plugin *ph, const char *id)
 	case 0x30f5a8: /* host */
 		return sess->server->hostname;
 
+	case 0x1c0e99c1: /* inputbox */
+		return fe_get_inputbox_contents (sess);
+
+	case 0x325acab5:	/* libdirfs */
+		return XCHATLIBDIR;
+
 	case 0x6de15a2e:	/* network */
-		return sess->server->networkname;
+		return get_network (sess, FALSE);
 
 	case 0x339763: /* nick */
 		return sess->server->nick;
@@ -1166,7 +1176,7 @@ xchat_list_str (xchat_plugin *ph, xchat_list *xlist, const char *name)
 		case 0x38b735af: /* context */
 			return data;	/* this is a session * */
 		case 0x6de15a2e: /* network */
-			return ((session *)data)->server->networkname;
+			return get_network ((session *)data, FALSE);
 		case 0x8455e723: /* nickprefixes */
 			return ((session *)data)->server->nick_prefixes;
 		case 0x829689ad: /* nickmodes */
@@ -1367,5 +1377,5 @@ xchat_send_modes (xchat_plugin *ph, const char **targets, int ntargets, int mode
 {
 	char tbuf[514];	/* modes.c needs 512 + null */
 
-	send_channel_modes (ph->context, tbuf, targets, 0, ntargets, sign, mode, modes_per_line);
+	send_channel_modes (ph->context, tbuf, (char **)targets, 0, ntargets, sign, mode, modes_per_line);
 }
