@@ -43,6 +43,7 @@
 #include "util.h"
 #include "../../config.h"
 
+#define WANTSOCKET
 #include "inet.h"
 
 #if defined (USING_FREEBSD) || defined (__APPLE__)
@@ -357,14 +358,21 @@ errorstring (int err)
 }
 
 int
-waitline (int sok, char *buf, int bufsize)
+waitline (int sok, char *buf, int bufsize, int use_recv)
 {
 	int i = 0;
 
 	while (1)
 	{
-		if (read (sok, &buf[i], 1) < 1)
-			return -1;
+		if (use_recv)
+		{
+			if (recv (sok, &buf[i], 1, 0) < 1)
+				return -1;
+		} else
+		{
+			if (read (sok, &buf[i], 1) < 1)
+				return -1;
+		}
 		if (buf[i] == '\n' || bufsize == i + 1)
 		{
 			buf[i] = 0;
@@ -481,7 +489,7 @@ get_cpu_info (double *mhz, int *cpus)
 
 	while (1)
 	{
-		if (waitline (fh, buf, sizeof buf) < 0)
+		if (waitline (fh, buf, sizeof buf, FALSE) < 0)
 			break;
 		if (!strncmp (buf, "cycle frequency [Hz]\t:", 22))	/* alpha */
 		{
@@ -840,7 +848,7 @@ country (char *hostname)
 		{"CF", N_("Central African Republic") },
 		{"CG", N_("Congo") },
 		{"CH", N_("Switzerland") },
-		{"CI", N_("Cote D'ivoire") },
+		{"CI", N_("Cote d'Ivoire") },
 		{"CK", N_("Cook Islands") },
 		{"CL", N_("Chile") },
 		{"CM", N_("Cameroon") },
@@ -890,7 +898,7 @@ country (char *hostname)
 		{"GP", N_("Guadeloupe") },
 		{"GQ", N_("Equatorial Guinea") },
 		{"GR", N_("Greece") },
-		{"GS", N_("S. Georgia and S. Sandwich Isles.") },
+		{"GS", N_("S. Georgia and S. Sandwich Isles") },
 		{"GT", N_("Guatemala") },
 		{"GU", N_("Guam") },
 		{"GW", N_("Guinea-Bissau") },
@@ -1039,7 +1047,7 @@ country (char *hostname)
 		{"UY", N_("Uruguay") },
 		{"UZ", N_("Uzbekistan") },
 		{"VA", N_("Vatican City State") },
-		{"VC", N_("St. Vincent and the grenadines") },
+		{"VC", N_("St. Vincent and the Grenadines") },
 		{"VE", N_("Venezuela") },
 		{"VG", N_("British Virgin Islands") },
 		{"VI", N_("US Virgin Islands") },
@@ -1495,3 +1503,22 @@ download_move_to_completed_dir (char *dcc_dir, char *dcc_completed_dir,
 			unlink (dl_src);
 	}
 }
+
+int
+mkdir_utf8 (char *dir)
+{
+	int ret;
+
+	dir = g_filename_from_utf8 (dir, -1, 0, 0, 0);
+	if (!dir)
+		return -1;
+
+#ifdef WIN32
+	ret = mkdir (dir);
+#else
+	ret = mkdir (dir, S_IRUSR | S_IWUSR | S_IXUSR);
+#endif
+	g_free (dir);
+
+	return ret;
+}
