@@ -62,7 +62,7 @@
 #include "xtext.h"
 
 static void mg_create_entry (session *sess, GtkWidget *box);
-static void mg_link_irctab (session *sess);
+static void mg_link_irctab (session *sess, int focus);
 
 static session_gui static_mg_gui;
 static session_gui *mg_gui = NULL;	/* the shared irc tab */
@@ -74,9 +74,9 @@ GtkWidget *parent_window = NULL;			/* the master window */
 
 GtkStyle *input_style;
 
-PangoAttrList *newdata_list;
-PangoAttrList *nickseen_list;
-PangoAttrList *newmsg_list = NULL;
+static PangoAttrList *newdata_list;
+static PangoAttrList *nickseen_list;
+static PangoAttrList *newmsg_list;
 static PangoAttrList *plain_list = NULL;
 
 
@@ -86,12 +86,27 @@ mg_attr_list_create (GdkColor *col)
 	PangoAttribute *attr;
 	PangoAttrList *list;
 
-	attr = pango_attr_foreground_new (col->red, col->green, col->blue);
-	attr->start_index = 0;
-	attr->end_index = 0xffff;
-
 	list = pango_attr_list_new ();
-	pango_attr_list_insert (list, attr);
+
+	if (col)
+	{
+		attr = pango_attr_foreground_new (col->red, col->green, col->blue);
+		attr->start_index = 0;
+		attr->end_index = 0xffff;
+		pango_attr_list_insert (list, attr);
+	}
+
+	if (prefs.tab_small)
+	{
+#ifdef WIN32
+		attr = pango_attr_scale_new (PANGO_SCALE_SMALL);
+#else
+		attr = pango_attr_scale_new (PANGO_SCALE_X_SMALL);
+#endif
+		attr->start_index = 0;
+		attr->end_index = 0xffff;
+		pango_attr_list_insert (list, attr);
+	}
 
 	return list;
 }
@@ -99,19 +114,18 @@ mg_attr_list_create (GdkColor *col)
 static void
 mg_create_tab_colors (void)
 {
-	if (newmsg_list)
+	if (plain_list)
 	{
+		pango_attr_list_unref (plain_list);
 		pango_attr_list_unref (newmsg_list);
 		pango_attr_list_unref (newdata_list);
 		pango_attr_list_unref (nickseen_list);
 	}
 
-	newdata_list = mg_attr_list_create (&colors[20]);
-	nickseen_list = mg_attr_list_create (&colors[21]);
-	newmsg_list = mg_attr_list_create (&colors[22]);
-
-	if (!plain_list)
-		plain_list = pango_attr_list_new ();
+	plain_list = mg_attr_list_create (NULL);
+	newdata_list = mg_attr_list_create (&colors[COL_NEW_DATA]);
+	nickseen_list = mg_attr_list_create (&colors[COL_HILIGHT]);
+	newmsg_list = mg_attr_list_create (&colors[COL_NEW_MSG]);
 }
 
 #ifdef WIN32
@@ -189,7 +203,7 @@ fe_set_tab_color (struct session *sess, int col, int flash)
 	}
 
 #ifdef WIN32
-	if (flash)
+	if (flash && prefs.flash_hilight)
 		flash_window (sess->gui->window);
 #endif
 }
@@ -890,12 +904,7 @@ mg_create_sess_tree (GtkWidget *menu)
 		if (serv->servername[0] == 0)
 			top_item = gtk_menu_item_new_with_label (_("<none>"));
 		else
-		{
-			if (serv->networkname)
-				top_item = gtk_menu_item_new_with_label (serv->networkname);
-			else
-				top_item = gtk_menu_item_new_with_label (serv->servername);
-		}
+			top_item = gtk_menu_item_new_with_label (get_network (serv->front_session, TRUE));
 
 		gtk_menu_shell_prepend (GTK_MENU_SHELL (menu), top_item);
 		gtk_widget_show (top_item);
@@ -976,7 +985,7 @@ mg_close_sess (session *sess)
 static void
 mg_detach_tab_cb (GtkWidget *item, session *sess)
 {
-	mg_link_irctab (sess);
+	mg_link_irctab (sess, 0);
 }
 
 static void
@@ -1050,17 +1059,6 @@ mg_tab_press_cb (GtkWidget *wid, GdkEventButton *event, session *sess)
 
 	menu = gtk_menu_new ();
 
-	mg_create_icon_item (_("Close Tab"), GTK_STOCK_CLOSE, menu,
-								mg_destroy_tab_cb, wid);
-	if (sess)
-		mg_create_icon_item (_("Detach Tab"), GTK_STOCK_REDO, menu,
-									mg_detach_tab_cb, sess);
-
-	/* separator */
-	item = gtk_menu_item_new ();
-	gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
-	gtk_widget_show (item);
-
 	if (sess)
 	{
 		item = gtk_menu_item_new_with_label (sess->channel[0] ? sess->channel : _("<none>"));
@@ -1091,6 +1089,17 @@ mg_tab_press_cb (GtkWidget *wid, GdkEventButton *event, session *sess)
 	gtk_menu_item_set_submenu (GTK_MENU_ITEM (item), submenu);
 	gtk_widget_show (item);
 
+	/* separator */
+	item = gtk_menu_item_new ();
+	gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
+	gtk_widget_show (item);
+
+	mg_create_icon_item (_("Close Tab"), GTK_STOCK_CLOSE, menu,
+								mg_destroy_tab_cb, wid);
+	if (sess)
+		mg_create_icon_item (_("Detach Tab"), GTK_STOCK_REDO, menu,
+									mg_detach_tab_cb, sess);
+
 	if (sess && tabmenu_list)
 		menu_create (menu, tabmenu_list, sess->channel, FALSE);
 
@@ -1113,11 +1122,12 @@ mg_add_chan (session *sess)
 	sess->res->tab = tab_group_add (sess->gui->tabs_box, name, sess->server,
 											  sess, mg_tab_press_cb, mg_link_cb,
 											  prefs.truncchans, prefs.tab_dnd);
-	g_object_set_data (G_OBJECT (sess->res->tab), "sess", sess);
-
-	if (newmsg_list == NULL)
+	if (plain_list == NULL)
 		mg_create_tab_colors ();
 
+	tab_set_attrlist (sess->res->tab, plain_list);
+	g_object_set_data (G_OBJECT (sess->res->tab), "sess", sess);
+
 	g_signal_connect (G_OBJECT (sess->res->tab), "destroy",
 					      G_CALLBACK (mg_tabdestroy_cb), sess);
 
@@ -1342,12 +1352,12 @@ mg_changui_destroy (session *sess)
 }
 
 static void
-mg_link_irctab (session *sess)
+mg_link_irctab (session *sess, int focus)
 {
 	if (sess->gui->is_tab)
 	{
 		mg_changui_destroy (sess);
-		mg_changui_new (sess, sess->res, 0);
+		mg_changui_new (sess, sess->res, 0, focus);
 		mg_populate (sess);
 		xchat_is_quitting = FALSE;
 		return;
@@ -1355,7 +1365,7 @@ mg_link_irctab (session *sess)
 
 	mg_unpopulate (sess);
 	mg_changui_destroy (sess);
-	mg_changui_new (sess, sess->res, 1);
+	mg_changui_new (sess, sess->res, 1, focus);
 }
 
 static void
@@ -1378,7 +1388,7 @@ mg_link_cb (GtkWidget *but, gpointer userdata)
 		return;
 	}
 
-	mg_link_irctab (current_sess);
+	mg_link_irctab (current_sess, 0);
 }
 
 static int
@@ -1548,8 +1558,8 @@ mg_limit_entry_cb (GtkWidget * igad, gpointer userdata)
 static void
 mg_apply_entry_style (GtkWidget *entry)
 {
-	gtk_widget_modify_base (entry, GTK_STATE_NORMAL, &colors[19]);
-	gtk_widget_modify_text (entry, GTK_STATE_NORMAL, &colors[18]);
+	gtk_widget_modify_base (entry, GTK_STATE_NORMAL, &colors[COL_BG]);
+	gtk_widget_modify_text (entry, GTK_STATE_NORMAL, &colors[COL_FG]);
 	gtk_widget_modify_font (entry, input_style->font_desc);
 }
 
@@ -1659,7 +1669,7 @@ mg_create_topicbar (session *sess, GtkWidget *box, char *name)
 	GtkWidget *hbox, *topic, *bbox;
 	session_gui *gui = sess->gui;
 
-	gui->topic_bar = hbox = gtk_hbox_new (FALSE, 0);
+	gui->topic_bar = hbox = gtk_hbox_new (FALSE, 1);
 	gtk_box_pack_start (GTK_BOX (box), hbox, 0, 0, 0);
 
 	mg_create_link_buttons (hbox, NULL);
@@ -1922,7 +1932,7 @@ mg_create_userlist (session_gui *gui, GtkWidget *box, int pack)
 	if (prefs.style_namelistgad)
 	{
 		gtk_widget_set_style (ulist, input_style);
-		gtk_widget_modify_base (ulist, GTK_STATE_NORMAL, &colors[19]);
+		gtk_widget_modify_base (ulist, GTK_STATE_NORMAL, &colors[COL_BG]);
 	}
 
 	mg_create_meters (gui, vbox);
@@ -2114,6 +2124,30 @@ mg_switch_tab_cb (GtkWidget *tab, session *sess, gpointer family)
 		mg_show_generic_tab (active_tab);
 }
 
+/* compare two tabs (for tab sorting function) */
+
+static int
+mg_tabs_compare (session *a, session *b)
+{
+	/* this is for "Open Utilities in: Tabs" (i.e. sess is NULL) */
+	if (!a)
+		return 1;
+	if (!b)
+		return -1;
+
+	/* server tabs always go first */
+	if (a->type == SESS_SERVER)
+		return -1;
+
+	/* then channels */
+	if (a->type == SESS_CHANNEL && b->type != SESS_CHANNEL)
+		return -1;
+	if (a->type != SESS_CHANNEL && b->type == SESS_CHANNEL)
+		return 1;
+
+	return strcasecmp (a->channel, b->channel);
+}
+
 static void
 mg_create_tabs (session_gui *gui, GtkWidget *box)
 {
@@ -2122,7 +2156,8 @@ mg_create_tabs (session_gui *gui, GtkWidget *box)
 	if (prefs.tabs_position == 2 || prefs.tabs_position == 3)
 		vert = TRUE;
 
-	gui->tabs_box = tab_group_new (mg_switch_tab_cb, vert, prefs.tab_sort);
+	gui->tabs_box = tab_group_new (mg_switch_tab_cb, mg_tabs_compare,
+											 vert, prefs.tab_sort);
 	gtk_table_attach (GTK_TABLE (gui->main_table), gui->tabs_box,
 						1, 2, 0, 1, GTK_FILL, GTK_FILL, 0, 0);
 }
@@ -2131,8 +2166,11 @@ static gboolean
 mg_tabwin_focus_cb (GtkWindow * win, GdkEventFocus *event, gpointer userdata)
 {
 	current_sess = current_tab;
-	gtk_xtext_check_marker_visibility(GTK_XTEXT (current_sess->gui->xtext));
-	plugin_emit_dummy_print (current_sess, "Focus Window");
+	if (current_sess)
+	{
+		gtk_xtext_check_marker_visibility (GTK_XTEXT (current_sess->gui->xtext));
+		plugin_emit_dummy_print (current_sess, "Focus Window");
+	}
 	return FALSE;
 }
 
@@ -2404,6 +2442,7 @@ mg_add_generic_tab (char *name, char *title, void *family, GtkWidget *box)
 	but = tab_group_add (mg_gui->tabs_box, name, family, NULL,
 								mg_tab_press_cb, mg_link_cb, prefs.truncchans,
 								prefs.tab_dnd);
+	tab_set_attrlist (but, plain_list);
 	g_object_set_data (G_OBJECT (but), "title", strdup (title));
 	g_object_set_data (G_OBJECT (but), "box", box);
 	g_object_set_data (G_OBJECT (but), "sess", NULL);
@@ -2571,7 +2610,7 @@ fe_set_channel (session *sess)
 }
 
 void
-mg_changui_new (session *sess, restore_gui *res, int tab)
+mg_changui_new (session *sess, restore_gui *res, int tab, int focus)
 {
 	int first_run = FALSE;
 	session_gui *gui;
@@ -2625,7 +2664,8 @@ mg_changui_new (session *sess, restore_gui *res, int tab)
 
 	mg_add_chan (sess);
 
-	if (first_run || prefs.newtabstofront)
+	if (first_run || (prefs.newtabstofront == FOCUS_NEW_ONLY_ASKED && focus)
+			|| prefs.newtabstofront == FOCUS_NEW_ALL )
 		tab_focus (res->tab);
 
 /*	while (g_main_pending ())
